@@ -179,13 +179,15 @@ _("FAQ|F");
 _("Table of Contents|a");
 _("LaTeX Configuration|L");
 _("About LyX|X");
+_("ACT");
+_("AMS");
+_("AT_RISE:");
 _("Abstract");
 _("Accepted");
 _("Acknowledgement");
 _("Acknowledgement*");
 _("Acknowledgements");
 _("Acknowledgments");
-_("ACT");
 _("Addchap");
 _("Addchap*");
 _("Addition");
@@ -197,21 +199,20 @@ _("Adresse");
 _("Affil");
 _("Affiliation");
 _("Algorithm");
-_("AMS");
 _("And");
 _("Anlagen");
 _("Anrede");
 _("Appendices");
 _("Appendix");
 _("Arrow");
-_("AT_RISE:");
 _("Author");
 _("Author_Email");
-_("Authorgroup");
-_("Authorinfo");
 _("Author_Running");
 _("Author_URL");
+_("Authorgroup");
+_("Authorinfo");
 _("Axiom");
+_("BLZ");
 _("Backaddress");
 _("Bank");
 _("BankAccount");
@@ -219,19 +220,17 @@ _("BankCode");
 _("Betreff");
 _("Bibliography");
 _("Biography");
-_("BLZ");
 _("BoardCentered");
 _("Brieftext");
+_("CC");
+_("CURTAIN");
 _("Caption");
 _("Case");
-_("cc");
-_("CC");
 _("CenteredCaption");
 _("Chapter");
 _("Chapter*");
 _("Chapter_Exercises");
 _("ChessBoard");
-_("Citta");
 _("Claim");
 _("Claim*");
 _("Closing");
@@ -249,9 +248,7 @@ _("Corollary*");
 _("Criterion");
 _("CrossList");
 _("Current_Address");
-_("CURTAIN");
 _("Customer");
-_("Data");
 _("Date");
 _("Datum");
 _("Dedication");
@@ -260,23 +257,22 @@ _("Definition");
 _("Definition*");
 _("Description");
 _("Dialogue");
-_("Email");
 _("EMail");
-_("encl");
-_("Encl.");
+_("EXT.");
+_("Email");
 _("Encl");
+_("Encl.");
 _("End_All_Slides");
 _("Enumerate");
 _("Example");
 _("Example*");
 _("Exercise");
-_("EXT.");
 _("Extratitle");
+_("FADE_IN:");
+_("FADE_OUT");
+_("FADE_OUT:");
 _("Fact");
 _("Fact*");
-_("FADE_IN:");
-_("FADE_OUT:");
-_("FADE_OUT");
 _("FigCaption");
 _("FirstAuthor");
 _("FirstName");
@@ -289,16 +285,16 @@ _("FourAuthors");
 _("FrontMatter");
 _("General");
 _("Gruss");
+_("HTTP");
 _("Headnote");
 _("HideMoves");
 _("HighLight");
-_("HTTP");
+_("INT.");
+_("INTERCUT");
 _("IhrSchreiben");
 _("IhrZeichen");
 _("Institute");
 _("Institution");
-_("INT.");
-_("INTERCUT");
 _("InvisibleText");
 _("Invoice");
 _("Itemize");
@@ -307,11 +303,11 @@ _("Keyword");
 _("Keywords");
 _("KnightMove");
 _("Konto");
+_("LaTeX");
+_("LaTeX_Title");
 _("Labeling");
 _("Land");
 _("LandscapeSlide");
-_("LaTeX");
-_("LaTeX_Title");
 _("Left_Header");
 _("Lemma");
 _("Lemma*");
@@ -329,10 +325,10 @@ _("MathLetters");
 _("MeinZeichen");
 _("Minisec");
 _("More");
-_("msnumber");
-_("My_Address");
-_("Myref");
 _("MyRef");
+_("My_Address");
+_("My_Logo");
+_("Myref");
 _("Name");
 _("Narrative");
 _("Notation");
@@ -342,16 +338,15 @@ _("NoteToEditor");
 _("Offprint");
 _("Offprints");
 _("Offsets");
-_("Oggetto");
 _("Opening");
 _("Ort");
 _("Overlay");
 _("PACS");
+_("PS");
 _("Paragraph");
 _("Paragraph*");
 _("Part");
 _("Part*");
-_("Petit");
 _("Phone");
 _("Place");
 _("PlaceFigure");
@@ -367,40 +362,40 @@ _("Proof");
 _("Property");
 _("Proposition");
 _("Proposition*");
-_("ps");
-_("PS");
 _("Publishers");
 _("Question");
 _("Quotation");
 _("Quote");
+_("REVTEX_Title");
 _("Received");
 _("Reference");
 _("References");
 _("Remark");
 _("Remark*");
 _("Remarks");
+_("Restriction");
 _("RetourAdresse");
 _("ReturnAddress");
 _("Revision");
 _("RevisionHistory");
 _("RevisionRemark");
-_("REVTEX_Title");
-_("Right_Address");
-_("Right_Header");
 _("RightHeader");
+_("Right_Address");
+_("Right_Footer");
+_("Right_Header");
 _("Rotatefoilhead");
 _("RunningAuthor");
-_("Running_LaTeX_Title");
 _("RunningTitle");
-_("Scene");
+_("Running_LaTeX_Title");
 _("SCENE");
 _("SCENE*");
+_("SGML");
+_("Scene");
 _("Scrap");
 _("Section");
 _("Section*");
 _("Send_To_Address");
 _("Seriate");
-_("SGML");
 _("ShortFoilhead");
 _("ShortRotatefoilhead");
 _("ShortTitle");
@@ -418,24 +413,27 @@ _("Standard");
 _("State");
 _("Strasse");
 _("Street");
-_("Subject");
-_("Subjectclass");
-_("Subparagraph");
-_("Subparagraph*");
-_("Subsection");
-_("Subsection*");
 _("SubSection");
-_("Subsubsection");
-_("Subsubsection*");
-_("Subtitle");
 _("SubTitle");
 _("SubVariation");
 _("SubVariation2");
 _("SubVariation3");
 _("SubVariation4");
 _("SubVariation5");
+_("Subject");
+_("Subjectclass");
+_("Subparagraph");
+_("Subparagraph*");
+_("Subsection");
+_("Subsection*");
+_("Subsubsection");
+_("Subsubsection*");
+_("Subtitle");
 _("Summary");
 _("Surname");
+_("TITLE_OVER:");
+_("TOC_Author");
+_("TOC_Title");
 _("TableComments");
 _("TableRefs");
 _("Telefax");
@@ -453,36 +451,35 @@ _("ThreeAuthors");
 _("TickList");
 _("Title");
 _("Titlehead");
-_("TITLE_OVER:");
-_("TOC_Author");
-_("TOC_Title");
 _("Topic");
 _("Town");
 _("Transition");
-_("Trans_Keywords");
-_("TranslatedAbstract");
-_("Translated_Title");
 _("Translator");
 _("TwoAffiliations");
 _("TwoAuthors");
+_("URL");
 _("Unterschrift");
 _("Uppertitleback");
-_("URL");
 _("Variation");
 _("Verbatim");
 _("Verse");
 _("Verteiler");
 _("VisibleText");
-_("Yourmail");
 _("YourMail");
-_("Yourref");
 _("YourRef");
+_("Yourmail");
+_("Yourref");
 _("Zusatz");
+_("cc");
+_("encl");
+_("msnumber");
+_("ps");
 _("Afrikaans");
 _("American");
 _("Arabic");
 _("Austrian");
 _("Bahasa");
+_("Belarusian");
 _("Basque");
 _("Portuguese (Brazil)");
 _("Breton");
@@ -508,6 +505,7 @@ _("Greek");
 _("Hebrew");
 _("Irish");
 _("Italian");
+_("Kazakh");
 _("Lsorbian");
 _("Magyar");
 _("Norsk");
@@ -762,9 +760,6 @@ _("&Restore")
 _("OK")
 _("&Apply")
 _("Cancel")
-_("LaTeX Error")
-_("LaTeX error messages")
-_("&Close")
 _("ERT inset display")
 _("&Inline")
 _("Show ERT inline")
@@ -774,6 +769,9 @@ _("&Open")
 _("Show ERT contents")
 _("OK")
 _("&Close")
+_("LaTeX Error")
+_("LaTeX error messages")
+_("&Close")
 _("External Material")
 _("&Template")
 _("Available templates")
