@@ -1,10 +1,10 @@
 // -*- C++ -*-
 /* This file is part of*
- * ====================================================== 
+ * ======================================================
  *
  *           LyX, The Document Processor
- * 	 
- *	    Copyright (C) 1995 Matthias Ettrich
+ *
+ *	    Copyright 1995 Matthias Ettrich
  *
  * ====================================================== */
 
@@ -15,12 +15,12 @@
 #pragma interface
 #endif
 
-#include "lyxinset.h"
+#include "inset.h"
 #include "LString.h"
 #include "lyxlex.h"
 
 /** Insertion of accents
-  
+
   Proper handling of accented characters.
   This is class is supposed to handle all LaTeX accents, it
   is also possible that the class will change a bit so that
@@ -30,50 +30,51 @@
 class InsetLatexAccent : public Inset {
 public:
 	///
-	InsetLatexAccent(); 
+	InsetLatexAccent();
 	///
+	explicit
 	InsetLatexAccent(string const & string);
-#if 0     // the compiler generated version should be ok.
 	///
-	InsetLatexAccent(InsetLatexAccent const &);
-#endif
+	int ascent(BufferView *, LyXFont const &) const;
 	///
-	int Ascent(LyXFont const & font) const;
+	int descent(BufferView *, LyXFont const &) const;
 	///
-	int Descent(LyXFont const & font) const;
+	int width(BufferView *, LyXFont const &) const;
 	///
-	int Width(LyXFont const & font) const;
+	void draw(BufferView *, LyXFont const &, int, float &, bool) const;
 	///
-	int Lbearing(LyXFont const & font) const;
+	int lbearing(LyXFont const & font) const;
 	///
-	int Rbearing(LyXFont const & font) const;
+	int rbearing(LyXFont const & font) const;
 	///
-	bool DisplayISO8859_9(LyXFont font, LyXScreen & scr,
-			      int baseline, float & x);
+	bool displayISO8859_9(BufferView *, LyXFont const & font,
+			      int baseline, float & x) const;
 	///
-	void Draw(LyXFont font, LyXScreen & scr, int baseline, float & x);
+	void write(Buffer const *, std::ostream &) const;
 	///
-	void Write(ostream &);
+	void read(Buffer const *, LyXLex & lex);
 	///
-	void Read(LyXLex & lex);
+	int latex(Buffer const *, std::ostream &,
+		  bool fragile, bool free_spc) const;
 	///
-	int Latex(ostream &, signed char fragile);
+	int ascii(Buffer const *, std::ostream &, int linelen) const;
 	///
-	int Latex(string & file, signed char fragile);
+	int linuxdoc(Buffer const *, std::ostream &) const;
 	///
-	int Linuxdoc(string & file);
+	int docbook(Buffer const *, std::ostream &) const;
 	///
-	int DocBook(string & file);
+	bool deletable() const;
 	///
-	bool Deletable() const;
+	bool directWrite() const;
 	///
-	bool DirectWrite() const;
+	virtual Inset * clone(Buffer const &, bool same_id = false) const;
 	///
-	Inset * Clone() const;
+	Inset::Code lyxCode()const;
 	///
-	Inset::Code LyxCode()const;
-	///
-	inline bool CanDisplay();
+	inline bool canDisplay();
+	// should this inset be handled like a normal charater
+	bool isChar() const { return true; }
+
 	/// all the accent types
 	enum ACCENT_TYPES{
 		///
@@ -113,14 +114,14 @@ public:
 		///
 		DOT_LESS_I,
 		///
- 		DOT_LESS_J, // 18
+		DOT_LESS_J, // 18
 		///
- 		lSLASH,
+		lSLASH,
 		///
- 		LSLASH
+		LSLASH
 	};
 private:
-	friend ostream & operator<<(ostream &, ACCENT_TYPES);
+	friend std::ostream & operator<<(std::ostream &, ACCENT_TYPES);
 	/// Check if we know the modifier and can display it ok on screen.
 	void checkContents();
 	///
@@ -129,7 +130,7 @@ private:
 	bool  candisp;
 	/// modifier type
 	ACCENT_TYPES  modtype;
-	
+
 	/// remove dot from 'i' and 'j' or transform l, L into lslash, LSLaSH
 	bool  remdot;
 	/// add something to ascent - accent at the top
@@ -137,10 +138,11 @@ private:
 	/// add something to descent - underlined char
 	bool  plusdesc;
 	/// international char
-	char  ic;    
+	mutable char  ic;
 };
 
-bool InsetLatexAccent::CanDisplay()
+
+bool InsetLatexAccent::canDisplay()
 {
 	return candisp;
 }
