@@ -3,9 +3,9 @@
  * ======================================================
  *
  *           LyX, The Document Processor
- * 	 
+ *
  *	    Copyright 1995 Matthias Ettrich
- *          Copyright 1995-1999 The LyX Team
+ *          Copyright 1995-2001 The LyX Team
  *
  * ====================================================== */
 
@@ -16,9 +16,10 @@
 #pragma interface
 #endif
 
-#include "lyxinset.h"
+#include "inset.h"
 
 class BufferParams;
+class Language;
 
 struct LaTeXFeatures;
 
@@ -26,8 +27,8 @@ struct LaTeXFeatures;
 /** Quotes.
 
   Used for the various quotes. German, English, French, all either
-  double or single **/ 
-class InsetQuotes: public Inset {
+  double or single **/
+class InsetQuotes : public Inset {
 public:
 	///
 	enum quote_language {
@@ -49,70 +50,77 @@ public:
 		///
 		LeftQ,
 		///
-		RightQ 
+		RightQ
 	};
 	///
 	enum quote_times {
 		///
 		SingleQ,
 		///
-		DoubleQ 
+		DoubleQ
 	};
-	
+
 	/** The constructor works like this:
 	  \begin{itemize}
-	    \item fls <- french single quote left 
-	    \item grd <- german double quote right 
+	    \item fls <- french single quote left
+	    \item grd <- german double quote right
 	    \item etc.
 	  \end{itemize}
-	  */ 
+	  */
+	explicit
 	InsetQuotes(string const & str = "eld");
 	/// Create the right quote inset after character c
 	InsetQuotes(char c, BufferParams const & params);
 
 	///
-	int Ascent(LyXFont const & font) const;
+	int ascent(BufferView *, LyXFont const &) const;
 	///
-	int Descent(LyXFont const & font) const;
+	int descent(BufferView *, LyXFont const &) const;
 	///
-	int Width(LyXFont const & font) const;
+	int width(BufferView *, LyXFont const &) const;
 	///
-	void Draw(LyXFont font, LyXScreen & scr, int baseline, float & x);
+	void draw(BufferView *, LyXFont const &, int, float &, bool) const;
+#if 0
 	///
-	LyXFont ConvertFont(LyXFont font);
+	LyXFont const convertFont(LyXFont const & font) const;
+#endif
 	///
-	void Write(ostream &);
+	void write(Buffer const *, std::ostream &) const;
 	///
-	void Read(LyXLex & lex);
+	void read(Buffer const *, LyXLex & lex);
 	///
-	int Latex(ostream &, signed char fragile);
+	int latex(Buffer const *, std::ostream &,
+		  bool fragile, bool free_spc) const;
 	///
-	int Latex(string & file, signed char fragile);
+	int ascii(Buffer const *, std::ostream &, int linelen) const;
 	///
-	int Linuxdoc(string & file);
+	int linuxdoc(Buffer const *, std::ostream &) const;
 	///
-	int DocBook(string & file);
+	int docbook(Buffer const *, std::ostream &) const;
 	///
-	void Validate(LaTeXFeatures &) const;
+	void validate(LaTeXFeatures &) const;
 	///
-	Inset * Clone() const;
+	virtual Inset * clone(Buffer const &, bool same_id = false) const;
 	///
-	Inset::Code LyxCode() const;
+	Inset::Code lyxCode() const;
+	// should this inset be handled like a normal charater
+	bool isChar() const { return true; }
+
 private:
 	///
-	quote_language language;
+	quote_language language_;
 	///
-	quote_side side;
+	quote_side side_;
 	///
-	quote_times times;
+	quote_times times_;
 
 	/** The parameters of the constructor are the language, the
 	    side and the multiplicity of the quote.
 	 */
 	InsetQuotes(quote_language l, quote_side s, quote_times t);
 	///
-	void ParseString(string const &);
+	void parseString(string const &);
 	///
-	string DispString() const;
+	string const dispString(Language const *) const;
 };
 #endif
