@@ -1,18 +1,21 @@
 // -*- C++ -*-
-/*
-  This file is part of
-  ======================================================
-  
-  LyX, The Document Processor
-  
-  Copyright (C) 1995 Matthias Ettrich
-  
-  ======================================================
-  */
+/* This file is part of
+ * ======================================================
+ *
+ *           LyX, The Document Processor
+ *
+ *           Copyright 1995 Matthias Ettrich
+ *           Copyright 1995-2001 The LyX Team.
+ *
+ * ====================================================== */
 
 #ifndef LYX_STY_H
 #define LYX_STY_H
 
+#ifdef __GNUG__
+#pragma interface
+#endif
+
 #include "LString.h"
 
 // This seems to be fixed now (JMarc)
@@ -29,20 +32,37 @@
 // another object. I'll let some others have a look now... (Lgb)
 
 // include this always
+///
 extern string const lyx_def;
+///
 extern string const lyxline_def;
+///
 extern string const noun_def;
+///
 extern string const lyxarrow_def;
+///
 extern string const quotedblbase_def;
+///
 extern string const quotesinglbase_def;
+///
 extern string const guillemotleft_def;
+///
 extern string const guillemotright_def;
+///
 extern string const guilsinglleft_def;
+///
 extern string const guilsinglright_def;
-extern string const paragraphindent_def;
+///
+extern string const paragraphleftindent_def;
+///
 extern string const floatingfootnote_def;
+///
 extern string const minipageindent_def;
+///
 extern string const boldsymbol_def;
+///
 extern string const binom_def;
+///
+extern string const mathcircumflex_def;
 
 #endif
